/*************************************************************/
/* File        : conversions.c                               */
/* Author      : Paul Lemmens (paul.lemmens@student.kun.nl)  */
/* Description : Defines the keyword-value struct            */
/* License     : GNU GPL                                     */
/*************************************************************/

/*
wmseti is a Windowmaker dockapp that displays seti@home client statistics.
Copyright (C) 2000 Paul Lemmens

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#include <stdio.h>

#include "conversions.h"
#include "global.h"

/***********************************************************************************/
/* secs_2_time converts seconds from double to a formatted time like hh:mm:ss into
 * time. Upon success returns the correctly formatted time. Upon failure, returns
 * 99:99:99. Assume that time has enough room (8 chars) to put the time into.*/
/***********************************************************************************/
char *secs_2_time(const double seconds, char *time)
{
	int h = 0, m = 0, s = 0;
	double secs = seconds;

	if ( DebugLevel >= 3 )
		fprintf(stderr, "\t\t\tConverting %f seconds to a timeformat\n", seconds);

	/* Set a default return value (error) which isn't changed until absolutely
	 * sure that it can be changed safely to a correct time format. */
	if ( strcpy(time, (char *)"99:99:99") == NULL )
	{
		fprintf(stderr, "\tconverting %f to a formatted time\n", seconds);
		return time;
	}

	if ( seconds < 0 )
		return time;

	/* Now convert seconds to formatted time. Don't forget seconds contains
	 * hundreds, so the remaining seconds need to be casted to an int. */
	if ( secs > 3600 )
	{
		h = secs / 3600;
		secs -= h * 3600;
	}
	else
		h = 0;
	m = secs / 60;
	secs -= m * 60;
	s = secs;

	sprintf(time, "%02d:%02d:%02d", h, m, s);
	time[8] = '\0';
	if ( DebugLevel >= 3 )
		fprintf(stderr, "\t\t\tReturned timeformat: %s\n", time);

	return time;
}
